@@ -2,7 +2,7 @@
 
 import string, textwrap
 import numpy as np
-from . import crm, infrared, molar, spectro, vindta, parameterisations, plot
+from . import crm, infrared, maps, molar, spectro, vindta, parameterisations, plot
 from .vindta import (
     Dbs,
     read_dbs,
@@ -29,7 +29,7 @@ from .vindta import (
 from .plot import get_cluster_profile, cluster_profile
 from .parameterisations import aou_GG92
 
-__version__ = "0.0.15"
+__version__ = "0.0.17"
 __author__ = "Humphreys, Matthew P."
 
 
